@@ -4,7 +4,9 @@ A crate for running processes on a virtual desktop / virtual X server environmen
 
 ## Usage
 This will spawn `some program` on a virtual desktop / virtual X server environment.
-```rs
+```rust
+# use std::process::*;
+# use transparent::*;
 Command::new("some program")
     .spawn_transparent(&TransparentRunner::new())
     .unwrap()
@@ -14,7 +16,7 @@ Command::new("some program")
 
 ## How it works
 ### Windows
-On windows `transparent` uses [`CreateProcessW`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-createdesktopw) to create a new desktop and then spawns a child process using [`CreateProcessW`](https://docs.microsoft.com/en-us/windows/win32/api/processthreadsapi/nf-processthreadsapi-createprocessw) with [`lpStartupInfo.lpDesktop`](https://docs.microsoft.com/en-us/windows/win32/api/processthreadsapi/ns-processthreadsapi-startupinfow#syntax) set to the new desktop. (Actually a helper process is spawned which then in turn spawns the target process; see [`virtual-desktop-runner`](https://github.com/OpenByteDev/transparent/tree/master/virtual-desktop-runner)).
+On windows `transparent` uses [`CreateDesktopW`](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-createdesktopw) to create a new desktop and then spawns a child process using [`CreateProcessW`](https://docs.microsoft.com/en-us/windows/win32/api/processthreadsapi/nf-processthreadsapi-createprocessw) with [`lpStartupInfo.lpDesktop`](https://docs.microsoft.com/en-us/windows/win32/api/processthreadsapi/ns-processthreadsapi-startupinfow#syntax) set to the new desktop. (Actually a helper process is spawned which then in turn spawns the target process; see [`virtual-desktop-runner`](https://github.com/OpenByteDev/transparent/tree/master/virtual-desktop-runner)).
 
 ### Unix
 On unix `transparent` uses [`xvfb-run`](http://manpages.ubuntu.com/manpages/trusty/man1/xvfb-run.1.html) which runs the target application in a virtual X server environment.
@@ -117,14 +119,15 @@ impl DerefMut for TransparentChild {
     }
 }
 
+/// Extension trait for [`Command`] providing an alternative form of [`TransparentRunner::spawn_transparent`].
 pub trait CommandExt {
+    /// Spawns the given [`Command`] transparently:
+    ///  - on windows it is spawned on a new virtual desktop
+    ///  - on unix it is spawned in a virtual X server environment
     fn spawn_transparent(&self, runner: &TransparentRunner) -> io::Result<TransparentChild>;
 }
 
 impl CommandExt for Command {
-    /// Spawns the given [`Command`] transparently:
-    ///  - on windows it is spawned on a new virtual desktop
-    ///  - on unix it is spawned in a virtual X server environment
     fn spawn_transparent(&self, runner: &TransparentRunner) -> io::Result<TransparentChild> {
         runner.spawn_transparent(self)
     }
